@@ -14,7 +14,7 @@ from starlette.datastructures import UploadFile
 
 # _home = os.path.expanduser('~')
 # xdg_cache_home = os.environ.get('XDG_CACHE_HOME') or os.path.join(_home, '.cache')
-APP_GROBID_URI = os.environ.get('APP_GROBID_URI', "https://sherpa-grobid.kairntech.com")
+APP_GROBID_URI = os.environ.get('APP_GROBID_URI', "https://cloud.science-miner.com/grobid")
 
 
 class GrobidParameters(ConverterParameters):
