@@ -17,3 +17,5 @@ def test_grobid_xml():
         assert docs[0].text
         assert docs[0].title
         assert 'TITLE' in docs[0].boundaries
+        assert docs[0].annotations
+        assert len(docs[0].annotations[0].terms) == 1
